==> plover_local_env_var-0.2.0-py3-none-any.whl: plover_local_env_var/env_var/expand.py <==
"""
Env Var - a module for dealing with fetching local ENV var values.
"""
import os
import re


_ENV_VAR = re.compile(r"(\$[A-Za-z_][A-Za-z_0-9]*)")
_DEFAULT_SHELL = "bash"
_INTERACTIVE_SHELLS = ["zsh", "bash"]
_VAR_DIVIDER = "##"

def expand(var: str) -> str:
    """
    Fetches and returns a single local env var value.

    Raises an error if `var` is not an ENV var or a value for the env var
    cannot be found.
    """
    if not re.match(_ENV_VAR, var):
        raise ValueError(f"Provided value not an $ENV_VAR: {var}")

    expanded = _perform_expansion(var)

    if not expanded:
        raise ValueError(f"No value found for env var: {var}")

    return expanded

def expand_list(var_name_list: list) -> dict[str, str]:
    """
    Returns a dict of env var values from a list of env var names.

    Removes a var from the list if:
        - its name not an ENV var
        - its value is blank.
    """
    var_name_list = [
        var_name for var_name in var_name_list if re.match(_ENV_VAR, var_name)
    ]
    var_names = _VAR_DIVIDER.join(var_name_list)
    expanded = _perform_expansion(var_names)
    env_vars = dict(zip(var_name_list, expanded.split(_VAR_DIVIDER)))
    valid_env_vars = {key: value for (key, value) in env_vars.items() if value}

    return valid_env_vars

def _perform_expansion(target: str) -> str:
    """
    Get user's shell and drive what flags to use
    """
    shell = os.environ.get("SHELL", _DEFAULT_SHELL)
    # NOTE: Using an interactive mode command (bash/zsh -ci) seemed to be the
    # only way to access a user's env vars on a Mac outside Plover's
    # environment.
    flags = "-ci" if shell in _INTERACTIVE_SHELLS else "-c"
    return os.popen(f"{shell} {flags} 'echo {target}'").read().strip()

==> plover_local_env_var-0.2.2-py3-none-any.whl: plover_local_env_var/env_var/expand.py <==
"""
Env Var - a module for dealing with fetching local ENV var values.
"""
import os
import re


_ENV_VAR = re.compile(r"(\$[A-Za-z_][A-Za-z_0-9]*)")
_DEFAULT_SHELL = "bash"
_INTERACTIVE_SHELLS = ["zsh", "bash"]
_VAR_DIVIDER = "##"

def expand(var: str) -> str:
    """
    Fetches and returns a single local env var value.

    Raises an error if `var` is not an ENV var or a value for the env var
    cannot be found.
    """
    if not re.match(_ENV_VAR, var):
        raise ValueError(f"Provided value not an $ENV_VAR: {var}")

    expanded = _perform_expansion(var)

    if not expanded:
        raise ValueError(f"No value found for env var: {var}")

    return expanded

def expand_list(var_name_list: list) -> dict[str, str]:
    """
    Returns a dict of env var values from a list of env var names.

    Removes a var from the list if:
        - its name not an ENV var
        - its value is blank.
    """
    var_name_list = [
        var_name for var_name in var_name_list if re.match(_ENV_VAR, var_name)
    ]
    var_names = _VAR_DIVIDER.join(var_name_list)
    expanded = _perform_expansion(var_names)
    env_vars = dict(zip(var_name_list, expanded.split(_VAR_DIVIDER)))
    valid_env_vars = {key: value for (key, value) in env_vars.items() if value}

    return valid_env_vars

def _perform_expansion(target: str) -> str:
    shell = os.environ.get("SHELL", _DEFAULT_SHELL).split("/")[-1]
    # NOTE: Using an interactive mode command (bash/zsh -ci) seemed to be the
    # only way to access a user's env vars on a Mac outside Plover's
    # environment.
    flags = "-ci" if shell in _INTERACTIVE_SHELLS else "-c"
    return os.popen(f"{shell} {flags} 'echo {target}'").read().strip()
